@@ -8,7 +8,7 @@ class server():
         self.port=port
     def run(self):
         path=os.path.join(self.bdir,'effront','manage.py')
-        os.system("python %s runserver 0.0.0.0:%s"%(path,self.port))
+        os.system("python %s migrate && python %s runserver 0.0.0.0:%s"%(path,path,self.port))
 
 class client():
     def __init__(self,clientName,host):
